<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!message" line="0"/>
			<source>Authentication is required to set service startup type</source>
			<translation>সেবা শুরুর ধরন নির্ধারণে পরিচালনা করতে জারিফিকেশন প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.systemmonitor.systemserver.set!description" line="0"/>
			<source>Set service startup type</source>
			<translation>সেবা শুরুর ধরন নির্ধারণ করুন</translation>
		</message>
	</context>
</TS>